@@ -48,7 +48,7 @@ class BackupDialog : public KDialogBase
 /**
  * @author Sbastien Laot <slaout@linux62.org>
  */
-class Backup
+class KDE_EXPORT Backup
 {
   public:
 	static void figureOutBinaryPath(const char *argv0, TQApplication &app);
